@@ -43,7 +43,7 @@ impl FileSystem {
             .map_err(|_| backend::FsError::IOError)?
     }
 
-    async fn create_dir(&self, path: &Path) -> FsResult<()> {
+    async fn create_dir(&self, path: &Path) -> FsResult<backend::Metadata> {
         debug!("create_dir: path={}", path.display());
 
         self.task
@@ -230,6 +230,17 @@ pub struct VirtualFile {
     meta: backend::Metadata,
 }
 
+impl Drop for VirtualFile {
+    fn drop(&mut self) {
+        let _ = self
+            .task
+            .call(backend::Close {})
+            .invoke()
+            .join::<FsResult<()>>()
+            .spawn();
+    }
+}
+
 impl Seek for VirtualFile {
     fn seek(&mut self, pos: SeekFrom) -> io::Result<u64> {
         let seek = match pos {
@@ -274,7 +285,7 @@ impl Read for VirtualFile {
     fn read(&mut self, buf: &mut [u8]) -> io::Result<usize> {
         let data: Result<Vec<u8>, io::Error> = self
             .task
-            .call(backend::Flush {})
+            .call(backend::Read { len: buf.len() as u64 })
             .invoke()
             .join::<FsResult<Vec<u8>>>()
             .wait()
